/*******************************************************************************

	DATA CLEANING FOR "When does decision-making reflect agency? Evidence 
					from the Rural Philippines"
						By: Forest Jarvis
				   Last modified: April 11, 2024
*******************************************************************************/

clear
clear matrix
clear mata
set more off
set maxvar 10000

// if c(username) == "WB471713" {
// global folder  "C:\Users\WB471713\OneDrive - WBG\EAPGIL\CARP Philippines\Analysis & Publications\Baseline\Decision-making & Autonomy\Replication package"
//
// }

// cd "$folder"

global mainbaseline "Main baseline master data.dta"
global spousalsurvey "Spousal survey master data.dta"
global rawdata "Spousal survey- raw data_anonymized.dta"


/***********************************************
0. Remove unsuccessful interviews and duplicates
************************************************

Note: Removal of PII has been commented out as de-anonymized raw data is not 
included in the replication package.

*Remove PII:

use "Spousal survey- raw data.dta", clear

drop name arbname_pl zone_pl parcel1formerowner_pl parcel1neighbor_pl parcel2formerowner_pl parcel2neighbor_pl parcel3formerowner_pl parcel3neighbor_pl correctname firstname lastname nickname nicknameyesno partnername arbname spousename othername contactnumber1 numberconf arbnumbernew contactnumber2 arbnumberpos2 facebookname facebooknamerel coordinateslatitude coordinateslongitude coordinatesaltitude

save "Spousal survey- raw data_anonymized.dta"

*/

use "$rawdata", clear

*Keep only complete interviews:

keep if interviewyesno==1
keep if consentyesno==1

*Correct mis-entered data:

replace respogender = 2 if arbid=="100687" & arbspouse==2 // Gender of respondent erroneously entered

*Remove double-entered interviews:

drop if key=="uuid:51981a2a-3e26-4d4d-b174-c0ea892433fa" & arbid=="100036"
drop if key=="uuid:e1b39912-c745-4813-a9b2-704a7ee7c205" & arbid=="100047"
drop if key=="uuid:94c0a5ea-88ec-4644-a45d-bc2d40265140" & arbid=="100059"

*Remove interview with incorrect ID:

drop if arbid=="101971" & key=="uuid:b03f0eb7-c391-40d6-8783-81c154711c39"
save "Spousal survey master data.dta", replace

/************************************
1. Generate decision-making variables
************************************/

tostring arbid, replace

gen id = arbid + "_Man" if respogender==1
replace id = arbid + "_Woman" if respogender==2

gen arbgender=. 
		replace arbgender=1 if arbspouse==1 & respogender==1
		replace arbgender=2 if arbspouse==2 & respogender==1
		replace arbgender=3 if arbspouse==1 & respogender==2
		replace arbgender=4 if arbspouse==2 & respogender==2
		
		label define gen 1"ARB Male" 2"Spouse Male" 3"ARB Female" 4"Spouse Female"
		label values arbgender gen
		
gen female = respogender==2

	label define decmaker 1"Man" 2"Woman" 3"Joint" 4"Other"

	gen cropgrow_dec = 1 if activitydecmaker_1==1 & arbgender==1
	replace cropgrow_dec = 1 if activitydecmaker_1==1 & arbgender==4
	replace cropgrow_dec = 1 if activitydecmaker_1==2 & arbgender==2
	replace cropgrow_dec = 1 if activitydecmaker_1==2 & arbgender==3
	replace cropgrow_dec = 2 if activitydecmaker_1==2 & arbgender==1
	replace cropgrow_dec = 2 if activitydecmaker_1==2 & arbgender==4
	replace cropgrow_dec = 2 if activitydecmaker_1==1 & arbgender==2
	replace cropgrow_dec = 2 if activitydecmaker_1==1 & arbgender==3
	replace cropgrow_dec = 3 if activitydecmaker_1==3
	replace cropgrow_dec = 4 if activitydecmaker_1==4
	replace cropgrow_dec = 4 if activitydecmaker_1==5
	replace cropgrow_dec = 4 if activitydecmaker_1==6
	replace cropgrow_dec = 4 if activitydecmaker_1==7

	label values cropgrow_dec decmaker

gen farmequipment_dec = 1 if activitydecmaker_2==1 & arbgender==1
	replace farmequipment_dec = 1 if activitydecmaker_2==1 & arbgender==4
	replace farmequipment_dec = 1 if activitydecmaker_2==2 & arbgender==2
	replace farmequipment_dec = 1 if activitydecmaker_2==2 & arbgender==3
	replace farmequipment_dec = 2 if activitydecmaker_2==2 & arbgender==1
	replace farmequipment_dec = 2 if activitydecmaker_2==2 & arbgender==4
	replace farmequipment_dec = 2 if activitydecmaker_2==1 & arbgender==2
	replace farmequipment_dec = 2 if activitydecmaker_2==1 & arbgender==3
	replace farmequipment_dec = 3 if activitydecmaker_2==3
	replace farmequipment_dec = 4 if activitydecmaker_2==4
	replace farmequipment_dec = 4 if activitydecmaker_2==5
	replace farmequipment_dec = 4 if activitydecmaker_2==6
	replace farmequipment_dec = 4 if activitydecmaker_2==7

	label values farmequipment_dec decmaker


gen cropsellchoice_dec = 1 if activitydecmaker_3==1 & arbgender==1
	replace cropsellchoice_dec = 1 if activitydecmaker_3==1 & arbgender==4
	replace cropsellchoice_dec = 1 if activitydecmaker_3==2 & arbgender==2
	replace cropsellchoice_dec = 1 if activitydecmaker_3==2 & arbgender==3
	replace cropsellchoice_dec = 2 if activitydecmaker_3==2 & arbgender==1
	replace cropsellchoice_dec = 2 if activitydecmaker_3==2 & arbgender==4
	replace cropsellchoice_dec = 2 if activitydecmaker_3==1 & arbgender==2
	replace cropsellchoice_dec = 2 if activitydecmaker_3==1 & arbgender==3
	replace cropsellchoice_dec = 3 if activitydecmaker_3==3
	replace cropsellchoice_dec = 4 if activitydecmaker_3==4
	replace cropsellchoice_dec = 4 if activitydecmaker_3==5
	replace cropsellchoice_dec = 4 if activitydecmaker_3==6
	replace cropsellchoice_dec = 4 if activitydecmaker_3==7

	label values cropsellchoice_dec decmaker

gen rearinglivestock_dec = 1 if activitydecmaker_4==1 & arbgender==1
	replace rearinglivestock_dec = 1 if activitydecmaker_4==1 & arbgender==4
	replace rearinglivestock_dec = 1 if activitydecmaker_4==2 & arbgender==2
	replace rearinglivestock_dec = 1 if activitydecmaker_4==2 & arbgender==3
	replace rearinglivestock_dec = 2 if activitydecmaker_4==2 & arbgender==1
	replace rearinglivestock_dec = 2 if activitydecmaker_4==2 & arbgender==4
	replace rearinglivestock_dec = 2 if activitydecmaker_4==1 & arbgender==2
	replace rearinglivestock_dec = 2 if activitydecmaker_4==1 & arbgender==3
	replace rearinglivestock_dec = 3 if activitydecmaker_4==3
	replace rearinglivestock_dec = 4 if activitydecmaker_4==4
	replace rearinglivestock_dec = 4 if activitydecmaker_4==5
	replace rearinglivestock_dec = 4 if activitydecmaker_4==6
	replace rearinglivestock_dec = 4 if activitydecmaker_4==7

	label values rearinglivestock_dec decmaker

gen nonfarmwork_dec = 1 if activitydecmaker_5==1 & arbgender==1
	replace nonfarmwork_dec = 1 if activitydecmaker_5==1 & arbgender==4
	replace nonfarmwork_dec = 1 if activitydecmaker_5==2 & arbgender==2
	replace nonfarmwork_dec = 1 if activitydecmaker_5==2 & arbgender==3
	replace nonfarmwork_dec = 2 if activitydecmaker_5==2 & arbgender==1
	replace nonfarmwork_dec = 2 if activitydecmaker_5==2 & arbgender==4
	replace nonfarmwork_dec = 2 if activitydecmaker_5==1 & arbgender==2
	replace nonfarmwork_dec = 2 if activitydecmaker_5==1 & arbgender==3
	replace nonfarmwork_dec = 3 if activitydecmaker_5==3
	replace nonfarmwork_dec = 4 if activitydecmaker_5==4
	replace nonfarmwork_dec = 4 if activitydecmaker_5==5
	replace nonfarmwork_dec = 4 if activitydecmaker_5==6
	replace nonfarmwork_dec = 4 if activitydecmaker_5==7

	label values nonfarmwork_dec decmaker

gen paidemployment_dec = 1 if activitydecmaker_6==1 & arbgender==1
	replace paidemployment_dec = 1 if activitydecmaker_6==1 & arbgender==4
	replace paidemployment_dec = 1 if activitydecmaker_6==2 & arbgender==2
	replace paidemployment_dec = 1 if activitydecmaker_6==2 & arbgender==3
	replace paidemployment_dec = 2 if activitydecmaker_6==2 & arbgender==1
	replace paidemployment_dec = 2 if activitydecmaker_6==2 & arbgender==4
	replace paidemployment_dec = 2 if activitydecmaker_6==1 & arbgender==2
	replace paidemployment_dec = 2 if activitydecmaker_6==1 & arbgender==3
	replace paidemployment_dec = 3 if activitydecmaker_6==3
	replace paidemployment_dec = 4 if activitydecmaker_6==4
	replace paidemployment_dec = 4 if activitydecmaker_6==5
	replace paidemployment_dec = 4 if activitydecmaker_6==6
	replace paidemployment_dec = 4 if activitydecmaker_6==7

	label values paidemployment_dec decmaker

gen majex_dec = 1 if activitydecmaker_8==1 & arbgender==1
	replace majex_dec = 1 if activitydecmaker_8==1 & arbgender==4
	replace majex_dec = 1 if activitydecmaker_8==2 & arbgender==2
	replace majex_dec = 1 if activitydecmaker_8==2 & arbgender==3
	replace majex_dec = 2 if activitydecmaker_8==2 & arbgender==1
	replace majex_dec = 2 if activitydecmaker_8==2 & arbgender==4
	replace majex_dec = 2 if activitydecmaker_8==1 & arbgender==2
	replace majex_dec = 2 if activitydecmaker_8==1 & arbgender==3
	replace majex_dec = 3 if activitydecmaker_8==3
	replace majex_dec = 4 if activitydecmaker_8==4
	replace majex_dec = 4 if activitydecmaker_8==5
	replace majex_dec = 4 if activitydecmaker_8==6
	replace majex_dec = 4 if activitydecmaker_8==7

	label values majex_dec decmaker

gen choosingseeds_dec = 1 if activitydecmaker2_1==1 & arbgender==1
	replace choosingseeds_dec = 1 if activitydecmaker2_1==1 & arbgender==4
	replace choosingseeds_dec = 1 if activitydecmaker2_1==2 & arbgender==2
	replace choosingseeds_dec = 1 if activitydecmaker2_1==2 & arbgender==3
	replace choosingseeds_dec = 2 if activitydecmaker2_1==2 & arbgender==1
	replace choosingseeds_dec = 2 if activitydecmaker2_1==2 & arbgender==4
	replace choosingseeds_dec = 2 if activitydecmaker2_1==1 & arbgender==2
	replace choosingseeds_dec = 2 if activitydecmaker2_1==1 & arbgender==3
	replace choosingseeds_dec = 3 if activitydecmaker2_1==3
	replace choosingseeds_dec = 4 if activitydecmaker2_1==4
	replace choosingseeds_dec = 4 if activitydecmaker2_1==5
	replace choosingseeds_dec = 4 if activitydecmaker2_1==6
	replace choosingseeds_dec = 4 if activitydecmaker2_1==7

	label values choosingseeds_dec decmaker

gen aginputbuy_dec = 1 if activitydecmaker2_2==1 & arbgender==1
	replace aginputbuy_dec = 1 if activitydecmaker2_2==1 & arbgender==4
	replace aginputbuy_dec = 1 if activitydecmaker2_2==2 & arbgender==2
	replace aginputbuy_dec = 1 if activitydecmaker2_2==2 & arbgender==3
	replace aginputbuy_dec = 2 if activitydecmaker2_2==2 & arbgender==1
	replace aginputbuy_dec = 2 if activitydecmaker2_2==2 & arbgender==4
	replace aginputbuy_dec = 2 if activitydecmaker2_2==1 & arbgender==2
	replace aginputbuy_dec = 2 if activitydecmaker2_2==1 & arbgender==3
	replace aginputbuy_dec = 3 if activitydecmaker2_2==3
	replace aginputbuy_dec = 4 if activitydecmaker2_2==4
	replace aginputbuy_dec = 4 if activitydecmaker2_2==5
	replace aginputbuy_dec = 4 if activitydecmaker2_2==6
	replace aginputbuy_dec = 4 if activitydecmaker2_2==7

	label values aginputbuy_dec decmaker

gen laborhire_dec = 1 if activitydecmaker2_3==1 & arbgender==1
	replace laborhire_dec = 1 if activitydecmaker2_3==1 & arbgender==4
	replace laborhire_dec = 1 if activitydecmaker2_3==2 & arbgender==2
	replace laborhire_dec = 1 if activitydecmaker2_3==2 & arbgender==3
	replace laborhire_dec = 2 if activitydecmaker2_3==2 & arbgender==1
	replace laborhire_dec = 2 if activitydecmaker2_3==2 & arbgender==4
	replace laborhire_dec = 2 if activitydecmaker2_3==1 & arbgender==2
	replace laborhire_dec = 2 if activitydecmaker2_3==1 & arbgender==3
	replace laborhire_dec = 3 if activitydecmaker2_3==3
	replace laborhire_dec = 4 if activitydecmaker2_3==4
	replace laborhire_dec = 4 if activitydecmaker2_3==5
	replace laborhire_dec = 4 if activitydecmaker2_3==6
	replace laborhire_dec = 4 if activitydecmaker2_3==7

	label values laborhire_dec decmaker

gen smallex_dec = 1 if activitydecmaker2_4==1 & arbgender==1
	replace smallex_dec = 1 if activitydecmaker2_4==1 & arbgender==4
	replace smallex_dec = 1 if activitydecmaker2_4==2 & arbgender==2
	replace smallex_dec = 1 if activitydecmaker2_4==2 & arbgender==3
	replace smallex_dec = 2 if activitydecmaker2_4==2 & arbgender==1
	replace smallex_dec = 2 if activitydecmaker2_4==2 & arbgender==4
	replace smallex_dec = 2 if activitydecmaker2_4==1 & arbgender==2
	replace smallex_dec = 2 if activitydecmaker2_4==1 & arbgender==3
	replace smallex_dec = 3 if activitydecmaker2_4==3
	replace smallex_dec = 4 if activitydecmaker2_4==4
	replace smallex_dec = 4 if activitydecmaker2_4==5
	replace smallex_dec = 4 if activitydecmaker2_4==6
	replace smallex_dec = 4 if activitydecmaker2_4==7
	
rename activities_1 cropgrow_part
rename activities_2 farmequipment_part
rename activities_3 cropsellchoice_part
rename activities_4 rearinglivestock_part
rename activities_5 nonfarmwork_part
rename activities_6 paidemployment_part
rename activities_8 majorexpenditures_part
rename activities2_1 choosingseeds_part
rename activities2_2 aginputbuy_part
rename activities2_3 laborhire_part
rename activities2_4 smallexpenditures_part


/***********************
2. Generate RAI variable
***********************/

*Recode RAI variables from high to low and generate one varlist for both genders
forval i=1/12{
	g motaut`i' = .
	g motaut`i'_c = .
	foreach f in male female{
		replace motaut`i' = 4 if motaut`f'`i'==1
		replace motaut`i' = 3 if motaut`f'`i'==2
		replace motaut`i' = 2 if motaut`f'`i'==3
		replace motaut`i' = 1 if motaut`f'`i'==4
		replace motaut`i'_c = 1 if !mi(motaut`i')
		}
}

*Rename RAI variables
rename motaut1 cropchoice_int
	rename motaut1_c cropchoice_int_c
rename motaut2* cropsell_nc*
rename motaut3* parcelsell_aut*
rename motaut4* parcelsell_int*
rename motaut5* cropchoice_aut*
rename motaut6* parcelsell_nc*
rename motaut7* cropsell_coe*
rename motaut8* cropchoice_nc*
rename motaut9* cropsell_int*
rename motaut10* cropsell_aut*
rename motaut11* parcelsell_coe*
rename motaut12* cropchoice_coe*

*Generate counts to check for missing values, drop those with incomplete RAI sections
egen autcount = rowtotal(*_aut_c)
egen intcount = rowtotal(*_int_c)

egen coecount = rowtotal(cropsell_coe_c cropchoice_coe_c parcelsell_coe_c)
egen altcount = rowtotal(*_aut_c *_int_c)

*Generate subscales:
egen autsubscale = rowtotal(*_aut)
	replace autsubscale = autsubscale/autcount
egen intsubscale = rowtotal(*_int)
	replace intsubscale = intsubscale/intcount
egen coesubscale = rowtotal(*_coe)
	replace coesubscale = coesubscale/coecount
egen altsubscale = rowtotal (*_aut *_int)
	replace altsubscale = altsubscale/altcount

	

*Generate Relative Autonomy Indices:	
gen rai = (altsubscale*3) + (coesubscale*-3)
	label var rai "RAI score (Two subscales)
	
replace rai = . if autcount<3
	replace rai = . if intcount<3
	replace rai = . if coecount<3
	
*Generate z-score standardized RAI:

sum rai
gen rai_z_a = (rai - `r(mean)')/`r(sd)'

sum rai if female
gen rai_z_f = (rai - `r(mean)')/`r(sd)'

sum rai if female==0
gen rai_z_m = (rai - `r(mean)')/`r(sd)'

save "Spousal survey - Decision-making.dta", replace

/*****************************************
3. Generate and merge in control variables
*****************************************/

use "$mainbaseline", clear

keep if qtype==1

*Remove duplicate interview:

drop arbid
gen arbid = substr(newid,1,6)

bysort newid: gen order = _n
drop if order==2

*3.1. Age:

gen spouse_age = hhmem1_age if hhmem1_relation==1

forval i=2/9{
	replace spouse_age = hhmem`i'_age if hhmem`i'_relation==1
	}

gen husband_age = age if sex==1
replace husband_age = spouse_age if sex==2

gen wife_age = age if sex==2
replace wife_age = spouse_age if sex==1

replace husband_age = 51 if farmerid=="103208"
replace wife_age = 32 if farmerid=="102279"
replace wife_age = 30 if farmerid=="101590"
replace wife_age = 32 if farmerid=="104182"
*Note: incorrect household member's age was used for the above cases.


gen agediff = husband_age - wife_age

*3.2. Household income:

local _w0 empincamt1 empincamt2 empincamt3 empincamt4 empincamt5 empincamt6 empincamt7 empincamt8 empincamt9 empincamt10 
local _w1 empinctohhyn1 empinctohhyn2 empinctohhyn3 empinctohhyn4 empinctohhyn5 empinctohhyn6 empinctohhyn7 empinctohhyn8 empinctohhyn9 empinctohhyn10 
local _w2 empinctohhamt1 empinctohhamt2 empinctohhamt3 empinctohhamt4 empinctohhamt5 empinctohhamt6 empinctohhamt7 empinctohhamt8 empinctohhamt9 empinctohhamt10

foreach var of varlist empinctohhyn1 empinctohhyn2 empinctohhyn3 empinctohhyn4 empinctohhyn5 empinctohhyn6 empinctohhyn7 empinctohhyn8 empinctohhyn9 empinctohhyn10 {

gettoken w0 _w0 : _w0
gettoken w1 _w1 : _w1
gettoken w2 _w2 : _w2

replace `w2'=`w0' if `w1'==1
replace `w2'=0 if `w0'==0

}

egen employ_incamt= rowtotal(empincamt1 empincamt2 empincamt3 empincamt4 empincamt5 empincamt6 empincamt7 empincamt8 empincamt9 empincamt10 empincamt11 empincamt12 empincamt13 empincamt14)
capture n replace employ_incamt =. if empincamt1==. & empincamt2==. & empincamt3==. & empincamt4==. & empincamt5==. & empincamt6==. & empincamt7==. & empincamt8==. & empincamt9==. & empincamt10==. & ///
 empincamt11==. & empincamt12==. & empincamt13==. & empincamt14==.
label var employ_incamt "Employment income of all HH members"

egen employ_incamttohh= rowtotal(empinctohhamt*)
capture n replace employ_incamttohh =. if empincamt1==. & empincamt2==. & empincamt3==. & empincamt4==. & empincamt5==. & empincamt6==. & empincamt7==. & empincamt8==. & empincamt9==. & empincamt10==. & ///
 empincamt11==. & empincamt12==. & empincamt13==. & empincamt14==.
label var employ_incamttohh "Employment income of all HH members (contributed to hh)"

egen buss_inc=rowtotal(busyn*)
replace buss_inc=1 if buss_inc>1 & buss_inc!=0
capture n replace buss_inc=. if busyn1==. & busyn2==. & busyn3==. & busyn4==. & busyn5==. & busyn6==. & busyn7==. & busyn8==. & busyn9==. & busyn10==. & busyn11==. & busyn12==. & busyn13==. & busyn14==. 
label var buss_inc "Over the last 4 months, did your household receive income from any personal business?"

egen buss_incamt=rowtotal(busincamt*)
replace buss_incamt=. if buss_inc==.
label var buss_incamt "Income received by household from any personal businesses"


egen total_hhinc = rowtotal(employ_incamttohh buss_incam incpensionamt incremitamt landlease_amt)
label var total_hhinc "Total household income"

gen total_hhinc_pc=total_hhinc/hhnum
label var total_hhinc_pc "Total per-capita household income"

gen lntotal_hhinc_pc=ln((total_hhinc + 1)/hhnum)
label var lntotal_hhinc_pc "Log of total per-capita household income"



*3.3. Income of spouses:

gen husbincome = empincamt1 if sex==1
	forval i=2/10{
		local j=`i'-1
		replace husbincome = empincamt`i' if hhmem`j'_relation==1 & sex==2
		}


gen wifeincome = empincamt1 if sex==2
	forval i=2/10{
		local j=`i'-1
		replace wifeincome = empincamt`i' if hhmem`j'_relation==1 & sex==1
		}	
		
gen incomediff = husbincome - wifeincome

*3.4 Education:

rename ed ed2

gen ed = 0 if ed2==1
replace ed = 0 if ed2==2
replace ed = 1 if ed2==3
replace ed = 2 if ed2==4
replace ed = 3 if ed2==5
replace ed = 4 if ed2==6
replace ed = 5 if ed2==7
replace ed = 6 if ed2==8
replace ed = 6 if ed2==9
replace ed = 7 if ed2==10
replace ed = 7 if ed2==11
replace ed = 8 if ed2==12
replace ed = 9 if ed2==13
replace ed = 10 if ed2==14
replace ed = 10 if ed2==15
replace ed = 11 if ed2==16
replace ed = 11 if ed2==18
replace ed = 11 if ed2==19
replace ed = 12 if ed2==20
replace ed = 13 if ed2==21
replace ed = 14 if ed2==22
replace ed = 14 if ed2==23
replace ed = 15 if ed2==24

*3.5. Parents/parents in law present in household

gen parentspresent = .
forval i=1/14{
	replace parentspresent = 1 if hhmem`i'_relation==3
}

*3.6. Merge with main dataset



keep arbid lntotal_hhinc_pc husband_age wife_age agediff husbincome wifeincome incomediff ed parentspresent plotnumtot hhnum total_hhinc_pc

save "Baseline control variables.dta", replace

use "Spousal survey - Decision-making.dta", clear

merge m:1 arbid using "Baseline control variables.dta", gen(controlmerge)

drop if controlmerge==2
drop if arbid==""

*3.7. Generate province variables:

ren province_pl province
g albay = province=="Albay"
g camsur = province=="Camarines Sur"
g bukidnon = province=="Bukidnon"
g comval = province=="Compostela Valley"
g davao = province=="Davao City"
g davor = province=="Davao Oriental"
g misor = province=="Misamis Oriental"
g northcot = province=="North Cotabato"
g sarangani = province=="Sarangani"
g southcot = province=="South Cotabato"
g sk = province=="Sultan Kudarat"
g surigao = province=="Surigao del Sur"
g davsur = province=="Davao del Sur"

*Note: simplifying provinces for respondents living in provinces adjacent to the location of their agricultural parcels.

replace province = "Davao del Sur" if province=="Davao City"
	replace province = "Sarangani" if province=="South Cotabato"

replace davor = 1 if surigao==1
	replace sarangani = 1 if southcot==1
	replace davsur = 1 if davao==1

	
*3.8. Female ARB:

gen arbfemale = female & arbspouse==1
	replace arbfemale = 1 if female==0 & arbspouse==2
	
*3.9. Female enumerator:

gen fo_female = inlist(foid, 39, 23, 12, 48, 36, 59, 11, 20, 8, 41, 46, 35)

*3.10 Wife has non-farm income:

gen wifenfincome = nonfarmwork_part==1 if female
replace wifenfincome = 1 if paidemployment_part==1 & female==1

gen husbnfincome = nonfarmwork_part==1 if female==0
replace husbnfincome = 1 if paidemployment_part==1 & female==0

*3.11 ARB status

gen arb = arbspouse==1

*3.11. Impute controls with median value:


foreach var in wife_age husband_age agediff parentspresent ed incomediff{
	gen `var'miss = `var'==.
	sum `var', d
	replace `var' = `r(p50)' if `var'miss==1
	}
	

****************************
*4. Generate outcome indices
****************************

global agactlist cropgrow farmequipment cropsellchoice rearinglivestock choosingseeds aginputbuy laborhire
global allactlist cropgrow farmequipment cropsellchoice rearinglivestock choosingseeds aginputbuy laborhire paidemployment majex smallex nonfarmwork
global agdeclist cropgrow_dec farmequipment_dec cropsellchoice_dec rearinglivestock_dec choosingseeds_dec aginputbuy_dec laborhire_dec
global alldeclist cropgrow_dec farmequipment_dec cropsellchoice_dec rearinglivestock_dec choosingseeds_dec aginputbuy_dec laborhire_dec paidemployment_dec majex_dec smallex_dec nonfarmwork_dec
global agpartlist cropgrow_part farmequipment_part cropsellchoice_part rearinglivestock_part choosingseeds_part aginputbuy_part laborhire_part
global allpartlist cropgrow_part farmequipment_part cropsellchoice_part rearinglivestock_part choosingseeds_part aginputbuy_part laborhire_part paidemployment_part majorexpenditures_part smallexpenditures_part nonfarmwork_part

*4.1. Decision-maker:

* Generate decision maker variables:

foreach var in $allactlist{
	gen `var'_decmaker = `var'_dec==3
	replace `var'_decmaker = 1 if `var'_dec==1 & female==0
	replace `var'_decmaker = 1 if `var'_dec==2 & female==1
	replace `var'_decmaker = . if `var'_dec==.
	
	gen `var'_soledec = `var'_dec==1 & female==0
	replace `var'_soledec = 1 if `var'_dec==2 & female==1
	replace `var'_soledec = . if `var'_dec==.
	
	}
	
global decmaker_ag cropgrow_decmaker farmequipment_decmaker cropsellchoice_decmaker rearinglivestock_decmaker choosingseeds_decmaker aginputbuy_decmaker laborhire_decmaker
global decmaker_all cropgrow_decmaker farmequipment_decmaker cropsellchoice_decmaker rearinglivestock_decmaker choosingseeds_decmaker aginputbuy_decmaker laborhire_decmaker paidemployment_decmaker majex_decmaker smallex_decmaker nonfarmwork_decmaker
global soledec_ag cropgrow_soledec farmequipment_soledec cropsellchoice_soledec rearinglivestock_soledec choosingseeds_soledec aginputbuy_soledec laborhire_soledec
global soledec_all cropgrow_soledec farmequipment_soledec cropsellchoice_soledec rearinglivestock_soledec choosingseeds_soledec aginputbuy_soledec laborhire_soledec paidemployment_soledec majex_soledec smallex_soledec nonfarmwork_soledec


*Aggregate totals:

foreach a in $allpartlist{
	replace `a' = 0 if `a'==3
	replace `a' = 1 if `a'==2
	}
	
egen allparttotal = rowtotal($allpartlist)
egen agparttotal = rowtotal($agpartlist)

egen agdecmakertotal = rowtotal($decmaker_ag)
egen alldecmakertotal = rowtotal($decmaker_all)
egen agsoledectotal = rowtotal($soledec_ag)
egen allsoledectotal = rowtotal($soledec_all)

*Ratios:

gen agdecmaker_pct = agdecmakertotal/agparttotal
gen alldecmaker_pct = alldecmakertotal/allparttotal

gen agsoledec_pct = agsoledectotal/agparttotal
gen allsoledec_pct = allsoledectotal/allparttotal

*Z-score indices:

foreach y in agdecmaker_pct alldecmaker_pct agsoledec_pct allsoledec_pct{
	sum `y'
	gen `y'_z_a = (`y'-`r(mean)')/`r(sd)'
	
	sum `y' if female==1
	gen `y'_z_f = (`y'-`r(mean)')/`r(sd)'
	replace `y'_z_f = . if female==0
	
	sum `y' if female==0
	gen `y'_z_m = (`y'-`r(mean)')/`r(sd)'
	replace `y'_z_m = . if female==1
}


*2.2. Levels of input:

*Rename variables:

rename activityinput_1 cropgrow_inp
rename activityinput_2 farmequipment_inp
rename activityinput_3 cropsellchoice_inp
rename activityinput_4 rearinglivestock_inp
rename activityinput_5 nonfarmwork_inp
rename activityinput_6 paidemployment_inp
rename activityinput_8 majex_inp
rename activityinput2_1 choosingseeds_inp
rename activityinput2_2 aginputbuy_inp
rename activityinput2_3 laborhire_inp
rename activityinput2_4 smallex_inp

*Generate indicators:

foreach a in $allactlist{
	gen `a'_highinp = `a'_inp==3
		replace `a'_highinp = . if `a'_inp==.
	gen `a'_hasinp = `a'_highinp
		replace `a'_hasinp = 1 if `a'_inp ==2
}

global all_highinp cropgrow_highinp farmequipment_highinp cropsellchoice_highinp rearinglivestock_highinp choosingseeds_highinp aginputbuy_highinp laborhire_highinp paidemployment_highinp majex_highinp smallex_highinp nonfarmwork_highinp
global ag_highinp cropgrow_highinp farmequipment_highinp cropsellchoice_highinp rearinglivestock_highinp choosingseeds_highinp aginputbuy_highinp laborhire_highinp

global all_hasinp cropgrow_hasinp farmequipment_hasinp cropsellchoice_hasinp rearinglivestock_hasinp choosingseeds_hasinp aginputbuy_hasinp laborhire_hasinp paidemployment_hasinp majex_hasinp smallex_hasinp nonfarmwork_hasinp
global ag_hasinp cropgrow_hasinp farmequipment_hasinp cropsellchoice_hasinp rearinglivestock_hasinp choosingseeds_hasinp aginputbuy_hasinp laborhire_hasinp 

*Aggregate totals:

egen allhighinptotal = rowtotal($all_highinp)
egen aghighinptotal = rowtotal($ag_highinp)
egen allhasinptotal = rowtotal($all_hasinp)
egen aghasinptotal = rowtotal($ag_hasinp)

*Ratios:

gen allhighinp_pct = allhighinptotal/allparttotal
gen aghighinp_pct = aghighinptotal/agparttotal

gen allhasinp_pct = allhasinptotal/allparttotal
gen aghasinp_pct = aghasinptotal/agparttotal

*Z-score indices:

foreach y in allhighinp_pct aghighinp_pct aghasinp_pct allhasinp_pct{
	sum `y'
	gen `y'_z_a = (`y'-`r(mean)')/`r(sd)'
	
	sum `y' if female==1
	gen `y'_z_f = (`y'-`r(mean)')/`r(sd)'
	replace `y'_z_f  = . if female==0
	
	sum `y' if female==0
	gen `y'_z_m = (`y'-`r(mean)')/`r(sd)'
	replace `y'_z_m = . if female==1
}


*2.3. Ability to make a decision:

*Rename variables:

rename activityautonomy_1 cropgrow_aut
rename activityautonomy_2 farmequipment_aut
rename activityautonomy_3 cropsellchoice_aut
rename activityautonomy_4 rearinglivestock_aut
rename activityautonomy_5 nonfarmwork_aut
rename activityautonomy_6 paidemployment_aut
rename activityautonomy_8 majex_aut
rename activityautonomy2_1 choosingseeds_aut
rename activityautonomy2_2 aginputbuy_aut
rename activityautonomy2_3 laborhire_aut
rename activityautonomy2_4 smallex_aut

*Generate indicators:

foreach a in $allactlist{
	gen `a'_highaut = `a'_aut==4
		replace `a'_highaut = . if `a'_aut==.
	gen `a'_highmedaut = `a'_highaut
		replace `a'_highmedaut = 1 if `a'_inp ==3
}

global all_highaut cropgrow_highaut farmequipment_highaut cropsellchoice_highaut rearinglivestock_highaut choosingseeds_highaut aginputbuy_highaut laborhire_highaut paidemployment_highaut majex_highaut smallex_highaut nonfarmwork_highaut
global ag_highaut cropgrow_highaut farmequipment_highaut cropsellchoice_highaut rearinglivestock_highaut choosingseeds_highaut aginputbuy_highaut laborhire_highaut

global all_highmedaut cropgrow_highmedaut farmequipment_highmedaut cropsellchoice_highmedaut rearinglivestock_highmedaut choosingseeds_highmedaut aginputbuy_highmedaut laborhire_highmedaut paidemployment_highmedaut majex_highmedaut smallex_highmedaut nonfarmwork_highmedaut 
global ag_highmedaut cropgrow_highmedaut farmequipment_highmedaut cropsellchoice_highmedaut rearinglivestock_highmedaut choosingseeds_highmedaut aginputbuy_highmedaut laborhire_highmedaut 

*Aggregate totals:

egen allhighauttotal = rowtotal($all_highaut)
egen aghighauttotal = rowtotal($ag_highaut)
egen allhighmedauttotal = rowtotal($all_highmedaut)
egen aghighmedauttotal = rowtotal($ag_highmedaut)

*Ratios:

gen allhighaut_pct = allhighauttotal/allparttotal
gen aghighaut_pct = aghighauttotal/agparttotal

gen allhighmedaut_pct = allhighmedauttotal/allparttotal
gen aghighmedaut_pct = aghighmedauttotal/agparttotal

foreach y in allhighaut_pct aghighaut_pct aghighmedaut_pct allhighmedaut_pct{
	sum `y'
	gen `y'_z_a = (`y'-`r(mean)')/`r(sd)'
	
	sum `y' if female==1
	gen `y'_z_f = (`y'-`r(mean)')/`r(sd)'
	replace `y'_z_f  = . if female==0
	
	sum `y' if female==0
	gen `y'_z_m = (`y'-`r(mean)')/`r(sd)'
	replace `y'_z_m = . if female==1
}


*Marital status:

gen married = maritalstatuspartner==1
gen commonlaw = maritalstatuspartner==3

*Total parcels formally owned:

gen totalparcelsowned = otherparcelcount + 1

*Household below food poverty threshold:

gen foodpoor = total_hhinc_pc<2517.67 //Note: assumes the 2018 food poverty threshold of PHP 7553 for a family of 5.
	replace foodpoor = . if total_hhinc_pc==.

save "Spousal survey- decision-making complete", replace

/*****************************************
5. Reshape and generate agreement measures
*****************************************/

keep arbid female albay camsur bukidnon davor misor northcot sarangani sk marriageyears relationshipyears *_part *_dec activityautonomy* ///
wifenfincome husbnfincome rai rai_z_* arbfemale fo_female wife_age wife_agemiss husband_age husband_agemiss agediff agediffmiss agparttotal parentspresent ed incomediff incomediffmiss ///
aghighinp_* aghighaut_* arb province married commonlaw totalparcelsowned foodpoor plotnumtot hhnum total_hhinc_pc

reshape wide albay camsur bukidnon davor misor northcot sarangani sk marriageyears relationshipyears *_part *_dec activityautonomy* ///
wifenfincome husbnfincome rai rai_z_* arbfemale fo_female wife_age wife_agemiss husband_age husband_agemiss agediff agediffmiss agparttotal parentspresent ed incomediff incomediffmiss ///
aghighinp_* aghighaut_* arb province married commonlaw totalparcelsowned foodpoor plotnumtot hhnum total_hhinc_pc, i(arbid) j(female)

rename *1 *_F
rename *0 *_M

rename rai_z_f_F rai_z_f
rename rai_z_m_M rai_z_m


*Agreement:
foreach act in $allactlist{
	gen agree_`act'_dec_m = `act'_dec_M==1 & `act'_dec_F==1
		replace agree_`act'_dec_m = 1 if `act'_dec_M==3 & `act'_dec_F==1
		replace agree_`act'_dec_m = 1 if `act'_dec_M==3 & `act'_dec_F==3
		replace agree_`act'_dec_m = 1 if `act'_dec_M==1 & `act'_dec_F==3
		replace agree_`act'_dec_m = . if `act'_dec_M==.
		replace agree_`act'_dec_m = . if `act'_dec_F==.
	gen agree_`act'_dec_f = `act'_dec_M==2 & `act'_dec_F==2
		replace agree_`act'_dec_f = 1 if `act'_dec_M==2 & `act'_dec_F==3
		replace agree_`act'_dec_f = 1 if `act'_dec_M==3 & `act'_dec_F==3
		replace agree_`act'_dec_f = 1 if `act'_dec_M==3 & `act'_dec_F==2
		replace agree_`act'_dec_f = . if `act'_dec_M==.
		replace agree_`act'_dec_f = . if `act'_dec_F==.
	gen agree_`act'_soledec_m = `act'_dec_M==1 & `act'_dec_F==1
		replace agree_`act'_soledec_m = . if `act'_dec_M==.
		replace agree_`act'_soledec_m = . if `act'_dec_F==.
	gen agree_`act'_soledec_f = `act'_dec_M==2 & `act'_dec_F==2
		replace agree_`act'_soledec_f = . if `act'_dec_M==.
		replace agree_`act'_soledec_f = . if `act'_dec_F==.
	}
	
global agpartlist_m cropgrow_part_M farmequipment_part_M cropsellchoice_part_M rearinglivestock_part_M choosingseeds_part_M aginputbuy_part_M laborhire_part_M
global agpartlist_f cropgrow_part_F farmequipment_part_F cropsellchoice_part_F rearinglivestock_part_F choosingseeds_part_F aginputbuy_part_F laborhire_part_F

foreach a in $agpartlist_f{
	replace `a' = 0 if `a'==3
	replace `a' = 1 if `a'==2
	}

foreach a in $agpartlist_f{
	replace `a' = 0 if `a'==3
	replace `a' = 1 if `a'==2
	}

global agree_decmaker_m agree_cropgrow_dec_m agree_farmequipment_dec_m agree_cropsellchoice_dec_m agree_rearinglivestock_dec_m agree_choosingseeds_dec_m agree_aginputbuy_dec_m agree_laborhire_dec_m
global agree_decmaker_f agree_cropgrow_dec_f agree_farmequipment_dec_f agree_cropsellchoice_dec_f agree_rearinglivestock_dec_f agree_choosingseeds_dec_f agree_aginputbuy_dec_f agree_laborhire_dec_f

global agree_soledec_m agree_cropgrow_soledec_m agree_farmequipment_soledec_m agree_cropsellchoice_soledec_m agree_rearinglivestock_soledec_m agree_choosingseeds_soledec_m agree_aginputbuy_soledec_m agree_laborhire_soledec_m
global agree_soledec_f agree_cropgrow_soledec_f agree_farmequipment_soledec_f agree_cropsellchoice_soledec_f agree_rearinglivestock_soledec_f agree_choosingseeds_soledec_f agree_aginputbuy_soledec_f agree_laborhire_soledec_f
	

egen agreedectotal_m = rowtotal($agree_decmaker_m)	
egen agreedectotal_f = rowtotal($agree_decmaker_f)	
egen agreesoletotal_m = rowtotal($agree_soledec_m)	
egen agreesoletotal_f = rowtotal($agree_soledec_f)

gen agreedecpct_m = agreedectotal_m/agparttotal_M
gen agreedecpct_f = agreedectotal_f/agparttotal_F
gen agreesolepct_m = agreesoletotal_m/agparttotal_M
gen agreesolepct_f = agreesoletotal_f/agparttotal_F
	
foreach y in agreedecpct_m agreedecpct_f agreesolepct_m agreesolepct_f{
	sum `y'
	gen `y'_z = (`y'-`r(mean)')/`r(sd)'
}

global provlist albay camsur bukidnon davor misor northcot sarangani sk

foreach var in agediff ed agediffmiss arb $provlist{
	gen `var' = `var'_M
	replace `var' = `var'_F if `var'_M ==.
}

foreach var in aghighinp_pct_z_f aghighaut_pct_z_f{
	gen `var' = `var'_F
}

foreach var in aghighinp_pct_z_m aghighaut_pct_z_m{
	gen `var' = `var'_M
}

gen matched = albay_M!=. & albay_F!=.

keep if matched==1

ren province_F province
ren husband_age_M husband_age
ren wife_age_F wife_age
ren married_F married
ren commonlaw_F commonlaw
ren totalparcelsowned_F totalparcelsowned
ren husbnfincome_M husbnfincome
ren wifenfincome_F wifenfincome
ren foodpoor_F foodpoor
ren plotnumtot_F plotnumtot
ren hhnum_F hhnum 
ren total_hhinc_pc_F total_hhinc_pc
ren arbfemale_F arbfemale

save "Spousal survey_wide.dta", replace










