/*******************************************************************************

	DATA ANALYSIS FOR "When does decision-making reflect agency? Evidence 
					from the Rural Philippines"
						By: Forest Jarvis
				   Last modified: April 11, 2024
*******************************************************************************/
cap log close

clear
clear matrix
clear mata
set more off
set maxvar 10000

global folder  "C:\WBG\github\RR_PHL_2024_154\Files for Replication Package"


cd "$folder"

sysdir set PLUS "${folder}\ado"
set varabbrev on

ssc install outreg
ssc install confa

log using "Arugay et al Forthcoming replication.smcl", replace

global mainbaseline "Main baseline master data.dta"
global spousalsurvey "Spousal survey master data.dta"
global maindata "Spousal survey- decision-making complete"
global widedata "Spousal survey_wide.dta"

global agactlist cropgrow farmequipment cropsellchoice rearinglivestock choosingseeds aginputbuy laborhire
global allactlist cropgrow farmequipment cropsellchoice rearinglivestock choosingseeds aginputbuy laborhire paidemployment majex smallex nonfarmwork
global agdeclist cropgrow_dec farmequipment_dec cropsellchoice_dec rearinglivestock_dec choosingseeds_dec aginputbuy_dec laborhire_dec
global alldeclist cropgrow_dec farmequipment_dec cropsellchoice_dec rearinglivestock_dec choosingseeds_dec aginputbuy_dec laborhire_dec paidemployment_dec majex_dec smallex_dec nonfarmwork_dec
global agpartlist cropgrow_part farmequipment_part cropsellchoice_part rearinglivestock_part choosingseeds_part aginputbuy_part laborhire_part
global allpartlist cropgrow_part farmequipment_part cropsellchoice_part rearinglivestock_part choosingseeds_part aginputbuy_part laborhire_part paidemployment_part majorexpenditures_part smallexpenditures_part nonfarmwork_part


do "Dataset generation.do"

use "$maindata", clear

/**************************************
1. Lasso selection of control variables
**************************************/

lasso linear rai_z_f (agdecmaker_pct_z_f aghighinp_pct_z_f aghighaut_pct_z_f) arb fo_female wife_age wife_agemiss husband_age husband_agemiss agediff agediffmiss parentspresent ed incomediff incomediffmiss albay camsur bukidnon davor misor northcot sarangani sk if female==1, nolog rseed(64278) selection(adaptive)
lassoknots

lasso linear rai_z_m (agdecmaker_pct_z_m aghighinp_pct_z_m aghighaut_pct_z_m) arb fo_female wife_age wife_agemiss husband_age husband_agemiss agediff agediffmiss parentspresent ed incomediff incomediffmiss albay camsur bukidnon davor misor northcot sarangani sk if female==0, nolog rseed(64278) selection(adaptive)
lassoknots

/*NOTE: Following lasso selection province indicators, age difference between spouses,
landowner status, and education were chosen as controls based on their selection across multiple lassos.
*/

global provlist albay camsur bukidnon davor misor northcot sarangani sk

global controls agediff ed agediffmiss arb $provlist 



/********************************************
2. Table 1: List of decision-making variables
*********************************************

Note: This table is not included in the replication package as it does not include
figures from the dataset, only question names.

***********************************************************************
3. Table 2: Example vignettes from Relative Autonomy Index (RAI) module
***********************************************************************

Note: This table is not included in the replication package as it does not include
figures from the dataset, only question names.

***************************************************************
4. Table 3: Descriptive statistics of decision-making by gender
***************************************************************

Note: This table was not generated using Stata, but the code to replicate the 
descriptive statistics can be found below.										*/
{
global alldecmaker cropgrow_decmaker farmequipment_decmaker cropsellchoice_decmaker rearinglivestock_decmaker choosingseeds_decmaker aginputbuy_decmaker laborhire_decmaker paidemployment_decmaker nonfarmwork_decmaker majex_decmaker smallex_decmaker 

global allsole cropgrow_soledec farmequipment_soledec cropsellchoice_soledec rearinglivestock_soledec choosingseeds_soledec aginputbuy_soledec laborhire_soledec paidemployment_soledec nonfarmwork_soledec majex_soledec smallex_soledec

global allagree_f agree_cropgrow_dec_f agree_farmequipment_dec_f agree_cropsellchoice_dec_f agree_rearinglivestock_dec_f agree_choosingseeds_dec_f agree_aginputbuy_dec_f agree_laborhire_dec_f agree_paidemployment_dec_f agree_nonfarmwork_dec_f agree_majex_dec_f agree_smallex_dec_f 

global allagree_m agree_cropgrow_dec_m agree_farmequipment_dec_m agree_cropsellchoice_dec_m agree_rearinglivestock_dec_m agree_choosingseeds_dec_m agree_aginputbuy_dec_m agree_laborhire_dec_m agree_paidemployment_dec_m agree_nonfarmwork_dec_m agree_majex_dec_m agree_smallex_dec_m 

global all_highinp cropgrow_highinp farmequipment_highinp cropsellchoice_highinp rearinglivestock_highinp choosingseeds_highinp aginputbuy_highinp laborhire_highinp paidemployment_highinp nonfarmwork_highinp majex_highinp smallex_highinp 

global all_highaut cropgrow_highaut farmequipment_highaut cropsellchoice_highaut rearinglivestock_highaut choosingseeds_highaut aginputbuy_highaut laborhire_highaut paidemployment_highaut nonfarmwork_highaut majex_highaut smallex_highaut

*Column 1:

dtable $alldecmaker if female

*Column 2: 

dtable $alldecmaker if female==0

*Column 3:

dtable $allsole if female

*Column 4:

dtable $allsole if female==0

clear

use "$widedata"

*Column 5: 

dtable $allagree_f

*Column 6:

dtable $allagree_m

clear

use "$maindata"

*Column 7:

dtable $all_highinp if female

*Column 8: 

dtable $all_highinp if female==0

*Column 9:

dtable $all_highaut if female

*Column 10:

dtable $all_highaut if female==0
}
/*************************************************************************
5. Table 4a: Relationship between decision-making measures and RAI (women)
**************************************************************************

Note: This code generates all figures found in Table 4a. The table itself 
has been slightly reformatted in the paper for ease of reading. 

*/
{

outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(t1)
outreg, clear(t2)

local _w1 "1 2 3"


	*1:
	qui reg rai_z_f agdecmaker_pct_z_f, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct_z_f)


	qui reg rai_z_f agdecmaker_pct_z_f $controls, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct_z_f)

	

clear

use "$widedata"

	*2:
	qui reg rai_z_f agreedecpct_f_z, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agreedecpct_f_z)

	
	qui reg rai_z_f agreedecpct_f_z $controls, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agreedecpct_f_z)



clear

use "$maindata"


	*3:
	qui reg rai_z_f aghighinp_pct_z_f, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct_z_f)
	
	qui reg rai_z_f aghighinp_pct_z_f $controls, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct_z_f)


	*4:
	qui reg rai_z_f aghighaut_pct_z_f, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct_z_f) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1n'"\"R2", "`r2n'"\"R3", "`r3n'"\"R4", "`r4n'")

	qui reg rai_z_f aghighaut_pct_z_f $controls, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct_z_f) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1c'"\"R2", "`r2c'"\"R3", "`r3c'"\"R4", "`r4c'")	

outreg using "${folder}/Autonomy Regressions_Table 4a", replace replay(row0) append(row1) store(t1) ///
ctitle(""\"", RAI (no controls), RAI(controls))

outreg using "${folder}/Autonomy Regressions_Table 4a", replace replay(t1) append(row2) store(t2) ///
ctitle(""\"", RAI (no controls), RAI(controls))
	

outreg using "${folder}/Autonomy Regressions_Table 4a", replace replay(t2) append(row3)  ///
rtitle(Decision-maker \ "" \ Agree woman is decision-maker \ "" \ High decision input \ "" \ High decision autonomy \ ///
"" \ N1 \ N2 \ N3 \ N4\ R1 \ R2 \ R3 \ R4) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"The decision-maker index represents the percentage of agricultural domains where the respondent reports being a decision-maker (either solely or jointly)." ///
	"High input represents the percentage of agricultural domains where the respondent reports having input on most or all decisions." ///
	"High decision ability represents the percentage of agricultural domains where the respondent reports being able to make their own decisions to a high extent." ///
	"All indices are transformed into z-scores." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title("Table 4a: Relationship between decision-making measures and autonomy (women)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", RAI (no controls), RAI(controls)) ///
	coljust(l;c) colwidth(24 9 9) nod
}

/***********************************************************************
6. Table 4b: Relationship between decision-making measures and RAI (men)
************************************************************************

Note: This code generates all figures found in Table 4b. The table itself 
has been slightly reformatted in the paper for ease of reading. 

*/
{

outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(row3)
outreg, clear(t1)
outreg, clear(t2)

local _w1 "1 2 3"


	*1:
	qui reg rai_z_m agdecmaker_pct_z_m, vce(robust)
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct_z_m)
	local n1: display %5.0f `e(N)'
	local r1n : display %4.3f `e(r2)'

	qui reg rai_z_m agdecmaker_pct_z_m $controls, vce(robust)
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct_z_m)
	local n1: display %5.0f `e(N)'
	local r1c : display %4.3f `e(r2)'
	

clear

use "$widedata"

	*2:
	qui reg rai_z_m agreedecpct_m_z, vce(robust)
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agreedecpct_m_z)
	local n2: display %5.0f `e(N)'
	local r2n : display %4.3f `e(r2)'
	
	qui reg rai_z_m agreedecpct_m_z $controls, vce(robust)
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agreedecpct_m_z)
	local n2: display %5.0f `e(N)'
	local r2c : display %4.3f `e(r2)'



clear

use "$maindata"


	*3:
	qui reg rai_z_m aghighinp_pct_z_m, vce(robust)
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct_z_m)
	local n3: display %5.0f `e(N)'
	local r3n : display %4.3f `e(r2)'
	
	qui reg rai_z_m aghighinp_pct_z_m $controls, vce(robust)
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct_z_m)
	local n3: display %5.0f `e(N)'
	local r3c : display %4.3f `e(r2)'


	*4:
	qui reg rai_z_m aghighaut_pct_z_m, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4 : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct_z_m) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1n'"\"R2", "`r2n'"\"R3", "`r3n'"\"R4", "`r4n'")

	qui reg rai_z_m aghighaut_pct_z_m $controls, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4 : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct_z_m) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1c'"\"R2", "`r2c'"\"R3", "`r3c'"\"R4", "`r4c'")	

outreg using "${folder}/Autonomy Regressions_Table 4b", replace replay(row0) append(row1) store(t1) ///
ctitle(""\"", RAI (no controls), RAI(controls))

outreg using "${folder}/Autonomy Regressions_Table 4b", replace replay(t1) append(row2) store(t2) ///
ctitle(""\"", RAI (no controls), RAI(controls))
	

outreg using "${folder}/Autonomy Regressions_Table 4b", replace replay(t2) append(row3) ///
rtitle(Decision-maker \ "" \ Agree man is decision-maker \ "" \ High decision input \ "" \ High decision autonomy \ ///
"" \ N1 \ N2 \ N3 \ N4\ R1 \ R2 \ R3 \ R4) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"The decision-maker index represents the percentage of agricultural domains where the respondent reports being a decision-maker (either solely or jointly)." ///
	"High input represents the percentage of agricultural domains where the respondent reports having input on most or all decisions." ///
	"High decision ability represents the percentage of agricultural domains where the respondent reports being able to make their own decisions to a high extent." ///
	"All indices are transformed into z-scores." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title("Table 4b: Relationship between decision-making measures and autonomy (men)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", RAI (no controls), RAI(controls)) ///
	coljust(l;c) colwidth(24 9 9) nod
}

/********************************************************************
7. Table 5: Relative association of decision-making measures with RAI
*********************************************************************

Note: This table has been reformatted in Microsoft Word 
due to limitations of the outreg command, which requires the coefficients
of variable names to appear in different rows of text.
*/

outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(row3)
outreg, clear(t1)
outreg, clear(t2)

	qui reg rai_z_f agdecmaker_pct_z_f aghighinp_pct_z_f aghighaut_pct_z_f $controls, vce(robust)
	local n1f: display %5.0f `e(N)'
	local r2f : display %4.3f `e(r2)'
	test agdecmaker_pct_z_f = aghighinp_pct_z_f
		local f1f: display %5.2f `r(F)'
	test agdecmaker_pct_z_f = aghighaut_pct_z_f
		local f2f: display %5.2f `r(F)'
	test aghighinp_pct_z_f = aghighaut_pct_z_f
		local f3f: display %5.2f `r(F)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct_z_f aghighinp_pct_z_f aghighaut_pct_z_f) ///
	addrows("Test Decision-maker = Input" , "`f1f'" \ "Test Decision-maker = Ability" , "`f2f'" \"Test Input = Ability" , "`f3f'" \"N" , "`n1f'" \"R2", "`r2f'")

	qui reg rai_z_m agdecmaker_pct_z_m aghighinp_pct_z_m aghighaut_pct_z_m $controls, vce(robust)
	local n1m: display %5.0f `e(N)'
	local r2m : display %4.3f `e(r2)'
	test agdecmaker_pct_z_m = aghighinp_pct_z_m
		local f1m: display %5.2f `r(F)'
	test agdecmaker_pct_z_m = aghighaut_pct_z_m
		local f2m: display %5.2f `r(F)'
	test aghighinp_pct_z_m = aghighaut_pct_z_m
		local f3m: display %5.2f `r(F)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct_z_m aghighinp_pct_z_m aghighaut_pct_z_m) ///
	addrows("Test Decision-maker = Input" , "`f1m'" \ "Test Decision-maker = Ability" , "`f2m'" \"Test Input = Ability" , "`f3m'" \"N" , "`n1m'" \"R2", "`r2m'")	
	

	
outreg using "${folder}/Autonomy Regressions Table 5", replace replay(row0) ///
rtitle(Decision-maker \ "" \ High decision input \ "" \ High decision autonomy \ ///
"" \ Test Decision-maker = Input \ Test Decision-maker = Ability \ Test Input = Ability \ N\ R2) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"The decision-maker index represents the percentage of agricultural domains where the respondent reports being a decision-maker (either solely or jointly)." ///
	"High input represents the percentage of agricultural domains where the respondent reports having input on most or all decisions." ///
	"High decision ability represents the percentage of agricultural domains where the respondent reports being able to make their own decisions to a high extent." ///
	"All indices are transformed into z-scores." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title(Table 5: Relative association of decision-making measures with RAI) addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", Women, Men) ///
	coljust(l;c) colwidth(24 9 9) nod

	
/********************************************************************
8. Table 6: Relative association of decision-making measures with RAI
*********************************************************************

Note: This table has been reformatted in Microsoft Word 
due to limitations of the outreg command, which requires the coefficients
of different variables to appear in different rows of text.
*/

use "$widedata", clear

outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(row3)
outreg, clear(t1)
outreg, clear(t2)

	qui reg rai_z_f agreedecpct_f_z aghighinp_pct_z_f aghighaut_pct_z_f $controls, vce(robust)
	local n1: display %5.0f `e(N)'
	local r2f : display %4.3f `e(r2)'
	test agreedecpct_f_z = aghighinp_pct_z_f
		local f1f: display %5.2f `r(F)'
	test agreedecpct_f_z = aghighaut_pct_z_f
		local f2f: display %5.2f `r(F)'
	test aghighinp_pct_z_f = aghighaut_pct_z_f
		local f3f: display %5.2f `r(F)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agreedecpct_f_z aghighinp_pct_z_f aghighaut_pct_z_f) ///
	addrows("Test Decision-maker = Input" , "`f1f'" \ "Test Decision-maker = Ability" , "`f2f'" \"Test Input = Ability" , "`f3f'" \"N" , "`n1'" \"R2", "`r2f'")

	qui reg rai_z_m agreedecpct_m_z aghighinp_pct_z_m aghighaut_pct_z_m $controls, vce(robust)
	local n1: display %5.0f `e(N)'
	local r2m : display %4.3f `e(r2)'
	test agreedecpct_m_z = aghighinp_pct_z_m
		local f1m: display %5.2f `r(F)'
	test agreedecpct_m_z = aghighaut_pct_z_m
		local f2m: display %5.2f `r(F)'
	test aghighinp_pct_z_m = aghighaut_pct_z_m
		local f3m: display %5.2f `r(F)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agreedecpct_m_z aghighinp_pct_z_m aghighaut_pct_z_m) ///
	addrows("Test Decision-maker = Input" , "`f1m'" \ "Test Decision-maker = Ability" , "`f2m'" \"Test Input = Ability" , "`f3m'" \"N" , "`n1'" \"R2", "`r2m'")	
	

	
outreg using "${folder}/Autonomy Regressions Table 6", replace replay(row0) ///
rtitle(Decision-maker \ "" \ High decision input \ "" \ High decision autonomy \ ///
"" \ Test Decision-maker = Input \ Test Decision-maker = Ability \ Test Input = Ability \ N\ R2) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"The decision-maker index represents the percentage of agricultural domains where the respondent reports being a decision-maker (either solely or jointly)." ///
	"High input represents the percentage of agricultural domains where the respondent reports having input on most or all decisions." ///
	"High decision ability represents the percentage of agricultural domains where the respondent reports being able to make their own decisions to a high extent." ///
	"All indices are transformed into z-scores." ///
	"LASSO-selected controls for the adjusted model include education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title(Table 6: Relative association of decision-making measures with RAI) addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", Women, Men) ///
	coljust(l;c) colwidth(24 9 9) nod
	
/****************************************************************
9. Appendix Table A1: Basic Demographic Characteristics of Sample
*****************************************************************

Note: This table was not generated using Stata, but the code to replicate the 
descriptive statistics can be found below.										*/

use "$maindata", clear

*Men and women:

tab female

*Province:

use "$widedata", clear

tab province

*Husband age:

sum husband_age

*Wife age:

sum wife_age

*Age difference:

sum agediff

*Couples in formal marriages:

tab married

*Couples in common-law marriages:

tab commonlaw

*ARB's education level:

sum ed

*Per capita monthly household income:

sum total_hhinc_pc

*Household below food poverty income threshold:

tab foodpoor

*Women with non-farm income

tab wifenfincome

*Men with non-farm income:

tab husbnfincome

*Female agrarian reform beneficiary:

tab arbfemale

*Parcels tilled by household:

sum plotnumtot

*Parcels formally owned by household:

sum totalparcelsowned

*Household size:

sum hhnum


/*******************************************************
10. Appendix Table A2: Full RAI module of spousal survey
********************************************************

Note: This table is not included in the replication package as it does not include
figures from the dataset, only question names.


*****************************************************************************
11. Appendix Table B1: Results from an Exploratory Factor Analysis of the RAI
*****************************************************************************

Note: This table was created in Microsoft Word. This do-file includes the code 
necessary to produce the results in the table. 
*/

use "$maindata", clear

*EFA for women:
factor cropchoice_int cropchoice_aut cropchoice_coe cropsell_int cropsell_aut cropsell_coe parcelsell_int parcelsell_aut parcelsell_coe if female==1
rotate

*EFA for men:
factor cropchoice_int cropchoice_aut cropchoice_coe cropsell_int cropsell_aut cropsell_coe parcelsell_int parcelsell_aut parcelsell_coe if female==0
rotate

/****************************************************
12. Appendix B2: Results from CFA of a two-factor RAI
*****************************************************

Note: This code replicates the goodness of fit indices described in the text of 
Appendix B1.


*Confirmatory factor analysis of 2-factor model with correlated measurement errors
in parcel-selling category:
*/
confa (Coerced: cropchoice_coe cropsell_coe parcelsell_coe) (Aut_int: cropchoice_int cropchoice_aut cropsell_int cropsell_aut parcelsell_int parcelsell_aut), from(ones) corr(parcelsell_aut:parcelsell_int parcelsell_aut:parcelsell_coe parcelsell_int:parcelsell_coe) vce(sbentler)

*Goodness of fit indices for CFA:
estat fitindices

/**********************************************************
13. Table C1a: Decision-maker Status by domain (Women only)
***********************************************************
Note: Tables C1a-C1f have been reformatted in Microsoft Word 
due to limitations of the outreg command, which requires the coefficients
of different variables to appear in different rows of text.
*/

use "$maindata", clear

global decmaker_ag cropgrow_decmaker farmequipment_decmaker cropsellchoice_decmaker rearinglivestock_decmaker choosingseeds_decmaker aginputbuy_decmaker laborhire_decmaker

{
outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(t1)

local _w1 "1 2 3 4 5 6 7"

foreach var in $decmaker_ag{

	gettoken w1 _w1 : _w1	
	dis in red "`w1'"

	*1:
	qui reg rai_z_f `var' if female==1, robust
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var')
	
	*2:
	qui reg rai_z_f `var' $controls if female==1, robust
	mat P =r(table)
	scalar p`w1'=P[4,1]
	mat drop P
	local r2 : display %4.3f `e(r2)'
	local n: display %5.0f `e(N)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var') ///
	addrows("N" , "`n'" \"R2", "`r2'")
	}
preserve
	clear
	scalar ver = 1
	mat define pval = [p1 \ p2 \ p3 \ p4 \ p5 \ p6 \ p7]
	svmat pval, names(pval)
	rename pval1 pval
	do "qvalues_1_sharpened.do"
	mkmat bky06_qval
	mat Q=bky06_qval
	
	foreach x in 1 2 3 4 5 6 7{
	
	local q`x' : display %4.3f Q[`x',1]
	
	}
restore

outreg using "${folder}/Autonomy Regressions_Table C1a", replace replay(row0) append(row1) ///
rtitle(RAI (Unadjusted) \ "" \ RAI (Adjusted) \ "" \ N \ R2) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"Outcomes are indicator variables for whether the respondent considers themselves a decision-maker in the domain, either solely or jointly." ///
	"RAI has been converted into standard deviations." ///
	"R2 of the adjusted model is reported." ///
	"BKY (2006) Sharpened Q-Values of Impact (Adjusted Model): `q1' , `q2', `q3', `q4', `q5', `q6', `q7'." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title("Table C1a: Decision-maker status by domain (Women only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", Growing crops for sale and household consumption, Buying and selling farm equipment, Choosing where and how to sell crops, ///
	Rearing livestock, Choosing seeds for food and cash crops, Buying agricultural inputs such as fertilizer, Hiring and paying laborers) ///
	coljust(l;c) colwidth(24 9 9 9 9 9 9 9) nod
	}

/********************************************************
14. Table C1b: Decision-maker Status by domain (Men only)
********************************************************/

{
outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(t1)

local _w1 "1 2 3 4 5 6 7"

foreach var in $decmaker_ag{

	gettoken w1 _w1 : _w1	
	dis in red "`w1'"

	*1:
	qui reg rai_z_m `var' if female==0, robust
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var')
	
	*2:
	qui reg rai_z_m `var' $controls if female==0, robust
	mat P =r(table)
	scalar p`w1'=P[4,1]
	mat drop P
	local r2 : display %4.3f `e(r2)'
	local n: display %5.0f `e(N)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var') ///
	addrows("N1" , "`n'" \"R2", "`r2'")
	}
preserve
	clear
	scalar ver = 1
	mat define pval = [p1 \ p2 \ p3 \ p4 \ p5 \ p6 \ p7]
	svmat pval, names(pval)
	rename pval1 pval
	do "qvalues_1_sharpened.do"
	mkmat bky06_qval
	mat Q=bky06_qval
	
	foreach x in 1 2 3 4 5 6 7{
	
	local q`x' : display %4.3f Q[`x',1]
	
	}
restore

outreg using "${folder}/Autonomy Regressions_Table C1b", replace replay(row0) append(row1)  ///
rtitle(RAI (Unadjusted) \ "" \ RAI (Adjusted) \ "" \ N \ R2) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"Outcomes are indicator variables for whether the respondent considers themselves a decision-maker in the domain, either solely or jointly." ///
	"RAI has been converted into standard deviations." ///
	"R2 of the adjusted model is reported." ///
	"BKY (2006) Sharpened Q-Values of Impact (Adjusted Model): `q1', `q2', `q3', `q4', `q5', `q6', `q7'." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title("Table C1b: Decision-maker status by domain (Men only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", Growing crops for sale and household consumption, Buying and selling farm equipment, Choosing where and how to sell crops, ///
	Rearing livestock, Choosing seeds for food and cash crops, Buying agricultural inputs such as fertilizer, Hiring and paying laborers) ///
	coljust(l;c) colwidth(24 9 9 9 9 9 9 9) nod
	}


/***************************************************
15. Table C1c: Decision Input by domain (Women only)
***************************************************/
global ag_highinp cropgrow_highinp farmequipment_highinp cropsellchoice_highinp rearinglivestock_highinp choosingseeds_highinp aginputbuy_highinp laborhire_highinp

{
outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(t1)

local _w1 "1 2 3 4 5 6 7"

foreach var in $ag_highinp{

	gettoken w1 _w1 : _w1	
	dis in red "`w1'"

	*1:
	qui reg rai_z_f `var' if female==1, robust
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var')
	
	*2:
	qui reg rai_z_f `var' $controls if female==1, robust
	mat P =r(table)
	scalar p`w1'=P[4,1]
	mat drop P
	local r2 : display %4.3f `e(r2)'
	local n: display %5.0f `e(N)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var') ///
	addrows("N" , "`n'" \"R2", "`r2'")
	}
preserve
	clear
	scalar ver = 1
	mat define pval = [p1 \ p2 \ p3 \ p4 \ p5 \ p6 \ p7]
	svmat pval, names(pval)
	rename pval1 pval
	do "qvalues_1_sharpened.do"
	mkmat bky06_qval
	mat Q=bky06_qval
	
	foreach x in 1 2 3 4 5 6 7{
	
	local q`x' : display %4.3f Q[`x',1]
	
	}
restore

outreg using "${folder}/Autonomy Regressions_Table C1c", replace replay(row0) append(row1) ///
rtitle(RAI (Unadjusted) \ "" \ RAI (Adjusted) \ "" \ N \R2) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"Outcomes are indicator variables for whether the respondent reports having some or all decisions in the domain." ///
	"RAI has been converted into standard deviations." ///
	"R2 of the adjusted model is reported." ///
	"BKY (2006) Sharpened Q-Values of Impact (Adjusted Model): `q1' , `q2', `q3', `q4', `q5', `q6', `q7'." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///	
	title("Table C1c: Decision input by domain (Women only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", Growing crops for sale and household consumption, Buying and selling farm equipment, Choosing where and how to sell crops, ///
	Rearing livestock, Choosing seeds for food and cash crops, Buying agricultural inputs such as fertilizer, Hiring and paying laborers) ///
	coljust(l;c) colwidth(24 9 9 9 9 9 9 9) nod
	}

/*************************************************
16. Table C1d: Decision Input by domain (Men only)
*************************************************/

{
outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(t1)

local _w1 "1 2 3 4 5 6 7"

foreach var in $ag_highinp{

	gettoken w1 _w1 : _w1	
	dis in red "`w1'"

	*1:
	qui reg rai_z_m `var' if female==0, robust
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var')
	
	*2:
	qui reg rai_z_m `var' $controls if female==0, robust
	mat P =r(table)
	scalar p`w1'=P[4,1]
	mat drop P
	local r2 : display %4.3f `e(r2)'
	local n: display %5.0f `e(N)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var') ///
	addrows("N" , "`n'" \ "R2", "`r2'")
	}
preserve
	clear
	scalar ver = 1
	mat define pval = [p1 \ p2 \ p3 \ p4 \ p5 \ p6 \ p7]
	svmat pval, names(pval)
	rename pval1 pval
	do "qvalues_1_sharpened.do"
	mkmat bky06_qval
	mat Q=bky06_qval
	
	foreach x in 1 2 3 4 5 6 7{
	
	local q`x' : display %4.3f Q[`x',1]
	
	}
restore

outreg using "${folder}/Autonomy Regressions_Table C1d", replace replay(row0) append(row1) ///
rtitle(RAI (Unadjusted) \ "" \ RAI (Adjusted) \ "" \ N \ R2) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"Outcomes are indicator variables for whether the respondent reports having some or all decisions in the domain." ///
	"RAI has been converted into standard deviations." ///
	"R2 of the adjusted model is reported." ///
	"BKY (2006) Sharpened Q-Values of Impact (Adjusted Model): `q1' , `q2', `q3', `q4', `q5', `q6', `q7'." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///	
	title("Table C1d: Decision input by domain (Men only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", Growing crops for sale and household consumption, Buying and selling farm equipment, Choosing where and how to sell crops, ///
	Rearing livestock, Choosing seeds for food and cash crops, Buying agricultural inputs such as fertilizer, Hiring and paying laborers) ///
	coljust(l;c) colwidth(24 9 9 9 9 9 9 9) nod
	}	


/**************************************************************
17. Table C1e: Ability to make decisions by domain (Women only)
**************************************************************/
global ag_highaut cropgrow_highaut farmequipment_highaut cropsellchoice_highaut rearinglivestock_highaut choosingseeds_highaut aginputbuy_highaut laborhire_highaut

{
outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(t1)

local _w1 "1 2 3 4 5 6 7"

foreach var in $ag_highaut{

	gettoken w1 _w1 : _w1	
	dis in red "`w1'"

	*1:
	qui reg rai_z_f `var' if female==1, robust
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var')
	
	*2:
	qui reg rai_z_f `var' $controls if female==1, robust
	mat P =r(table)
	scalar p`w1'=P[4,1]
	mat drop P
	local r2 : display %4.3f `e(r2)'
	local n: display %5.0f `e(N)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var') ///
	addrows("N" , "`n'" \ "R2", "`r2'")
	}
preserve
	clear
	scalar ver = 1
	mat define pval = [p1 \ p2 \ p3 \ p4 \ p5 \ p6 \ p7]
	svmat pval, names(pval)
	rename pval1 pval
	do "qvalues_1_sharpened.do"
	mkmat bky06_qval
	mat Q=bky06_qval
	
	foreach x in 1 2 3 4 5 6 7{
	
	local q`x' : display %4.3f Q[`x',1]
	
	}
restore

outreg using "${folder}/Autonomy Regressions_Table C1e", replace replay(row0) append(row1)  ///
rtitle(RAI (Unadjusted) \ "" \ RAI (Adjusted) \ "" \ N \ R2) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"Outcomes are indicator variables for whether the respondent reports being able to make their own personal decisions in the domain if they wanted to." ///
	"RAI has been converted into standard deviations." ///
	"R2 of the adjusted model is reported." ///
	"BKY (2006) Sharpened Q-Values of Impact (Adjusted Model): `q1' , `q2', `q3', `q4', `q5', `q6', `q7'." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///	
	title("Table C1e: Ability to make decisions by domain (Women only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", Growing crops for sale and household consumption, Buying and selling farm equipment, Choosing where and how to sell crops, ///
	Rearing livestock, Choosing seeds for food and cash crops, Buying agricultural inputs such as fertilizer, Hiring and paying laborers) ///
	coljust(l;c) colwidth(24 9 9 9 9 9 9 9) nod
	}

/************************************************************
18. Table C1f: Ability to make decisions by domain (Men only)
************************************************************/


{
outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(t1)

local _w1 "1 2 3 4 5 6 7"

foreach var in $ag_highaut{

	gettoken w1 _w1 : _w1	
	dis in red "`w1'"

	*1:
	qui reg rai_z_m `var' if female==0, robust
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var')
	
	*2:
	qui reg rai_z_m `var' $controls if female==0, robust
	mat P =r(table)
	scalar p`w1'=P[4,1]
	mat drop P
	local r2 : display %4.3f `e(r2)'
	local n: display %5.0f `e(N)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(`var') ///
	addrows("N" , "`n'" \ "R2", "`r2'")
	}
preserve
	clear
	scalar ver = 1
	mat define pval = [p1 \ p2 \ p3 \ p4 \ p5 \ p6 \ p7]
	svmat pval, names(pval)
	rename pval1 pval
	do "qvalues_1_sharpened.do"
	mkmat bky06_qval
	mat Q=bky06_qval
	
	foreach x in 1 2 3 4 5 6 7{
	
	local q`x' : display %4.3f Q[`x',1]
	
	}
restore

outreg using "${folder}/Autonomy Regressions_Table C1f", replace replay(row0) append(row1)  ///
rtitle(RAI (Unadjusted) \ "" \ RAI (Adjusted) \ "" \ N \R2) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"Outcomes are indicator variables for whether the respondent reports being able to make their own personal decisions in the domain if they wanted to." ///
	"RAI has been converted into standard deviations." ///
	"R2 of the adjusted model is reported." ///
	"BKY (2006) Sharpened Q-Values of Impact (Adjusted Model): `q1' , `q2', `q3', `q4', `q5', `q6', `q7'." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///	
	title("Table C1f: Ability to make decisions by domain (Men only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", Growing crops for sale and household consumption, Buying and selling farm equipment, Choosing where and how to sell crops, ///
	Rearing livestock, Choosing seeds for food and cash crops, Buying agricultural inputs such as fertilizer, Hiring and paying laborers) ///
	coljust(l;c) colwidth(24 9 9 9 9 9 9 9) nod
	}
/************************************************
19. Table C2a: Decision-maker Status (Women only)
************************************************/
{
	


outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(row3)
outreg, clear(t1)
outreg, clear(t2)

local _w1 "1 2 3"


	*1:
	qui reg rai_z_f agdecmaker_pct_z_f, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct_z_f)


	qui reg rai_z_f agdecmaker_pct_z_f $controls, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct_z_f)

	*2:
	qui reg rai_z_f agdecmaker_pct if female==1, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct)


	qui reg rai_z_f agdecmaker_pct $controls if female==1, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct)

	*3:
	qui reg rai_z_f agsoledec_pct_z_f, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agsoledec_pct_z_f)
	
	qui reg rai_z_f agsoledec_pct_z_f $controls, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agsoledec_pct_z_f)


	*4:
	qui reg rai_z_f agsoledec_pct if female==1, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agsoledec_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1n'"\"R2", "`r2n'"\"R3", "`r3n'"\"R4", "`r4n'")

	qui reg rai_z_f agsoledec_pct $controls if female==1, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agsoledec_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1c'"\"R2", "`r2c'"\"R3", "`r3c'"\"R4", "`r4c'")	

outreg using "${folder}/Autonomy Regressions_Table C2a", replace replay(row0) append(row1) store(t1) ///
ctitle(""\"", RAI (no controls), RAI(controls))

outreg using "${folder}/Autonomy Regressions_Table C2a", replace replay(t1) append(row2) store(t2) ///
ctitle(""\"", RAI (no controls), RAI(controls))
	

outreg using "${folder}/Autonomy Regressions_Table C2a", replace replay(t2) append(row3)  ///
rtitle(Decision-maker index (z-score) \ "" \ Decision-maker index (percentage) \ "" \ Sole decision-maker (z-score) \ "" \ Sole decision-maker (percentage) \ ///
"" \ N1 \ N2 \ N3 \ N4\ R1 \ R2 \ R3 \ R4) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"The decision-maker index represents the percentage of agricultural domains where the respondent reports being a decision-maker (either solely or jointly)." ///
	"RAI has been converted into standard deviations." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title("C2a: Decision-maker Status (Women only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", RAI (no controls), RAI(controls)) ///
	coljust(l;c) colwidth(24 9 9) nod
}

/**********************************************
20. Table C2b: Decision-maker Status (Men only)
**********************************************/
{


outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(row3)
outreg, clear(t1)
outreg, clear(t2)

local _w1 "1 2 3"


	*1:
	qui reg rai_z_m agdecmaker_pct_z_m, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct_z_m)


	qui reg rai_z_m agdecmaker_pct_z_m $controls, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct_z_m)

	*2:
	qui reg rai_z_m agdecmaker_pct if female==0, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct)


	qui reg rai_z_m agdecmaker_pct $controls if female==0, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agdecmaker_pct)

	*3:
	qui reg rai_z_m agsoledec_pct_z_m, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agsoledec_pct_z_m)
	
	qui reg rai_z_m agsoledec_pct_z_m $controls, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agsoledec_pct_z_m)


	*4:
	qui reg rai_z_m agsoledec_pct if female==0, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agsoledec_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1n'"\"R2", "`r2n'"\"R3", "`r3n'"\"R4", "`r4n'")

	qui reg rai_z_m agsoledec_pct $controls if female==0, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(agsoledec_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1c'"\"R2", "`r2c'"\"R3", "`r3c'"\"R4", "`r4c'")	

outreg using "${folder}/Autonomy Regressions_Table C2b", replace replay(row0) append(row1) store(t1) ///
ctitle(""\"", RAI (no controls), RAI(controls))

outreg using "${folder}/Autonomy Regressions_Table C2b", replace replay(t1) append(row2) store(t2) ///
ctitle(""\"", RAI (no controls), RAI(controls))
	

outreg using "${folder}/Autonomy Regressions_Table C2b", replace replay(t2) append(row3)  ///
rtitle(Decision-maker index (z-score) \ "" \ Decision-maker index (percentage) \ "" \ Sole decision-maker (z-score) \ "" \ Sole decision-maker (percentage) \ ///
"" \ N1 \ N2 \ N3 \ N4\ R1 \ R2 \ R3 \ R4) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"The decision-maker index represents the percentage of agricultural domains where the respondent reports being a decision-maker (either solely or jointly)." ///
	"RAI has been converted into standard deviations." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title("C2b: Decision-maker Status (Men only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", RAI (no controls), RAI(controls)) ///
	coljust(l;c) colwidth(24 9 9) nod
}

/***********************************************
21. Table C2c: Input into Decisions (Women only)
***********************************************/
{

outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(row3)
outreg, clear(t1)
outreg, clear(t2)

local _w1 "1 2 3"


	*1:
	qui reg rai_z_f aghighinp_pct_z_f, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct_z_f)


	qui reg rai_z_f aghighinp_pct_z_f $controls, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct_z_f)

	*2:
	qui reg rai_z_f aghighinp_pct if female==1, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct)


	qui reg rai_z_f aghighinp_pct $controls if female==1, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct)

	*3:
	qui reg rai_z_f aghasinp_pct_z_f, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghasinp_pct_z_f)
	
	qui reg rai_z_f aghasinp_pct_z_f $controls, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghasinp_pct_z_f)


	*4:
	qui reg rai_z_f aghasinp_pct if female==1, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghasinp_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1n'"\"R2", "`r2n'"\"R3", "`r3n'"\"R4", "`r4n'")

	qui reg rai_z_f aghasinp_pct $controls if female==1, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghasinp_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1c'"\"R2", "`r2c'"\"R3", "`r3c'"\"R4", "`r4c'")	

outreg using "${folder}/Autonomy Regressions_Table C2c", replace replay(row0) append(row1) store(t1) ///
ctitle(""\"", RAI (no controls), RAI(controls))

outreg using "${folder}/Autonomy Regressions_Table C2c", replace replay(t1) append(row2) store(t2) ///
ctitle(""\"", RAI (no controls), RAI(controls))
	

outreg using "${folder}/Autonomy Regressions_Table C2c", replace replay(t2) append(row3)  ///
rtitle(Input on all decisions (z-score) \ "" \ Input on all decisions (percentage) \ "" \ Input on most or all decisions (z-score) \ "" \ Input on most or all decisions \ ///
"" \ N1 \ N2 \ N3 \ N4\ R1 \ R2 \ R3 \ R4) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"Outcomes represent the percentage of agricultural domains in which the respondent reports having input on decisions." ///
	"RAI has been converted into standard deviations." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title("C2c: Input into Decisions (Women only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", RAI (no controls), RAI(controls)) ///
	coljust(l;c) colwidth(24 9 9) nod
}

/*********************************************
22. Table C2d: Input into Decisions (Men only)
*********************************************/
{
	
use "$maindata", clear

outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(row3)
outreg, clear(t1)
outreg, clear(t2)

local _w1 "1 2 3"


	*1:
	qui reg rai_z_m aghighinp_pct_z_m, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct_z_m)


	qui reg rai_z_m aghighinp_pct_z_m $controls, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct_z_m)

	*2:
	qui reg rai_z_m aghighinp_pct if female==0, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct)


	qui reg rai_z_m aghighinp_pct $controls if female==0, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighinp_pct)

	*3:
	qui reg rai_z_m aghasinp_pct_z_m, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghasinp_pct_z_m)
	
	qui reg rai_z_m aghasinp_pct_z_m $controls, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghasinp_pct_z_m)


	*4:
	qui reg rai_z_m aghasinp_pct if female==0, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghasinp_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1n'"\"R2", "`r2n'"\"R3", "`r3n'"\"R4", "`r4n'")

	qui reg rai_z_m aghasinp_pct $controls if female==0, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghasinp_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1c'"\"R2", "`r2c'"\"R3", "`r3c'"\"R4", "`r4c'")	

outreg using "${folder}/Autonomy Regressions_Table C2d", replace replay(row0) append(row1) store(t1) ///
ctitle(""\"", RAI (no controls), RAI(controls))

outreg using "${folder}/Autonomy Regressions_Table C2d", replace replay(t1) append(row2) store(t2) ///
ctitle(""\"", RAI (no controls), RAI(controls))
	

outreg using "${folder}/Autonomy Regressions_Table C2d", replace replay(t2) append(row3)  ///
rtitle(Input on all decisions (z-score) \ "" \ Input on all decisions (percentage) \ "" \ Input on most or all decisions (z-score) \ "" \ Input on most or all decisions \ ///
"" \ N1 \ N2 \ N3 \ N4\ R1 \ R2 \ R3 \ R4) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"Outcomes represent the percentage of agricultural domains in which the respondent reports having input on decisions." ///
	"RAI has been converted into standard deviations." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title("C2d: Input into Decisions (Men only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", RAI (no controls), RAI(controls)) ///
	coljust(l;c) colwidth(24 9 9) nod
}

/*****************************************************
23. Table C2e: Ability to make a decision (Women only)
*****************************************************/
{

outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(row3)
outreg, clear(t1)
outreg, clear(t2)

local _w1 "1 2 3"


	*1:
	qui reg rai_z_f aghighaut_pct_z_f, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct_z_f)


	qui reg rai_z_f aghighaut_pct_z_f $controls, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct_z_f)

	*2:
	qui reg rai_z_f aghighaut_pct if female==1, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct)


	qui reg rai_z_f aghighaut_pct $controls if female==1, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct)

	*3:
	qui reg rai_z_f aghighmedaut_pct_z_f, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighmedaut_pct_z_f)
	
	qui reg rai_z_f aghighmedaut_pct_z_f $controls, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighmedaut_pct_z_f)


	*4:
	qui reg rai_z_f aghighmedaut_pct if female==1, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighmedaut_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1n'"\"R2", "`r2n'"\"R3", "`r3n'"\"R4", "`r4n'")

	qui reg rai_z_f aghighmedaut_pct $controls if female==1, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighmedaut_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1c'"\"R2", "`r2c'"\"R3", "`r3c'"\"R4", "`r4c'")	

outreg using "${folder}/Autonomy Regressions_Table C2e", replace replay(row0) append(row1) store(t1) ///
ctitle(""\"", RAI (no controls), RAI(controls))

outreg using "${folder}/Autonomy Regressions_Table C2e", replace replay(t1) append(row2) store(t2) ///
ctitle(""\"", RAI (no controls), RAI(controls))
	

outreg using "${folder}/Autonomy Regressions_Table C2e", replace replay(t2) append(row3)  ///
rtitle(High decision autonomy (z-score) \ "" \ High decision autonomy (percentage) \ "" \ High or medium decision autonomy (z-score) \ "" \ High or medium decision autonomy \ ///
"" \ N1 \ N2 \ N3 \ N4\ R1 \ R2 \ R3 \ R4) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"Outcomes represent the percentage of agricultural domains in which the respondent reports being able to make their own personal decisions if they wanted." ///
	"RAI has been converted into standard deviations." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title("C2e: Ability to make a decision (Women only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", RAI (no controls), RAI(controls)) ///
	coljust(l;c) colwidth(24 9 9) nod
}

/***************************************************
24. Table C2f: Ability to make a decision (Men only)
***************************************************/
{

outreg, clear
outreg, clear(row0)
outreg, clear(row1)
outreg, clear(row2)
outreg, clear(row3)
outreg, clear(t1)
outreg, clear(t2)

local _w1 "1 2 3"


	*1:
	qui reg rai_z_m aghighaut_pct_z_m, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct_z_m)


	qui reg rai_z_m aghighaut_pct_z_m $controls, vce(robust)
	local n1: display %5.0f `e(N)'
	local r1c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row0) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct_z_m)

	*2:
	qui reg rai_z_m aghighaut_pct if female==0, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct)


	qui reg rai_z_m aghighaut_pct $controls if female==0, vce(robust)
	local n2: display %5.0f `e(N)'
	local r2c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row1) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighaut_pct)

	*3:
	qui reg rai_z_m aghighmedaut_pct_z_m, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighmedaut_pct_z_m)
	
	qui reg rai_z_m aghighmedaut_pct_z_m $controls, vce(robust)
	local n3: display %5.0f `e(N)'
	local r3c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row2) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighmedaut_pct_z_m)


	*4:
	qui reg rai_z_m aghighmedaut_pct if female==0, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4n : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighmedaut_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1n'"\"R2", "`r2n'"\"R3", "`r3n'"\"R4", "`r4n'")

	qui reg rai_z_m aghighmedaut_pct $controls if female==0, vce(robust)
	local n4: display %5.0f `e(N)'
	local r4c : display %4.3f `e(r2)'
	outreg, nocons noautosumm merge(row3) varlabels bdec(3) se blankrows  starlevels(10 5 1) keep(aghighmedaut_pct) ///
	addrows("N1" , "`n1'" \"N2" , "`n2'" \"N3" , "`n3'" \"N4" , "`n4'" \"R1", "`r1c'"\"R2", "`r2c'"\"R3", "`r3c'"\"R4", "`r4c'")	

outreg using "${folder}/Autonomy Regressions_Table C2f", replace replay(row0) append(row1) store(t1) ///
ctitle(""\"", RAI (no controls), RAI(controls))

outreg using "${folder}/Autonomy Regressions_Table C2f", replace replay(t1) append(row2) store(t2) ///
ctitle(""\"", RAI (no controls), RAI(controls))
	

outreg using "${folder}/Autonomy Regressions_Table C2f", replace replay(t2) append(row3)  ///
rtitle(High decision autonomy (z-score) \ "" \ High decision autonomy (percentage) \ "" \ High or medium decision autonomy (z-score) \ "" \ High or medium decision autonomy \ ///
"" \ N1 \ N2 \ N3 \ N4\ R1 \ R2 \ R3 \ R4) ///
note("OLS models with marginal effects. Robust standard errors in parentheses.  * p<0.1 ** p<0.05; *** p<0.01" ///
	"Outcomes represent the percentage of agricultural domains in which the respondent reports being able to make their own personal decisions if they wanted." ///
	"RAI has been converted into standard deviations." ///
	"LASSO-selected controls for the adjusted model include ARB status, education, age difference between spouses, and province fixed effects.") bdec(3) se starlevels(10 5 1) statfont(arial) ///
	title("C2f: Ability to make a decision (Men only)") addfont(Palatino Linotype) basefont(fs9 fnew1) multicol(1,2,2) ///
	landscape titlfont(fs10 fnew1 b) hlstyle(s;d;;s) ///
	ctitle(""\"", RAI (no controls), RAI(controls)) ///
	coljust(l;c) colwidth(24 9 9) nod
}

log close
